@@ -1,24 +1,20 @@
 ( cd usr/lib ; rm -rf libcom_err.so )
 ( cd usr/lib ; ln -sf /lib/libcom_err.so.2 libcom_err.so )
-( cd usr/lib ; rm -rf libe2p.so )
-( cd usr/lib ; ln -sf /lib/libe2p.so.2 libe2p.so )
-( cd usr/lib ; rm -rf libext2fs.so )
-( cd usr/lib ; ln -sf /lib/libext2fs.so.2 libext2fs.so )
 ( cd usr/lib ; rm -rf libss.so )
 ( cd usr/lib ; ln -sf /lib/libss.so.2 libss.so )
-( cd usr/lib ; rm -rf libblkid.so )
-( cd usr/lib ; ln -sf /lib/libblkid.so.1 libblkid.so )
+( cd usr/lib ; rm -rf libe2p.so )
+( cd usr/lib ; ln -sf /lib/libe2p.so.2 libe2p.so )
 ( cd usr/lib ; rm -rf libuuid.so )
 ( cd usr/lib ; ln -sf /lib/libuuid.so.1 libuuid.so )
-( cd lib ; rm -rf libext2fs.so.2 )
-( cd lib ; ln -sf libext2fs.so.2.4 libext2fs.so.2 )
-( cd lib ; rm -rf libe2p.so.2 )
-( cd lib ; ln -sf libe2p.so.2.3 libe2p.so.2 )
-( cd lib ; rm -rf libss.so.2 )
-( cd lib ; ln -sf libss.so.2.0 libss.so.2 )
+( cd usr/lib ; rm -rf libext2fs.so )
+( cd usr/lib ; ln -sf /lib/libext2fs.so.2 libext2fs.so )
 ( cd lib ; rm -rf libcom_err.so.2 )
 ( cd lib ; ln -sf libcom_err.so.2.1 libcom_err.so.2 )
-( cd lib ; rm -rf libblkid.so.1 )
-( cd lib ; ln -sf libblkid.so.1.0 libblkid.so.1 )
+( cd lib ; rm -rf libss.so.2 )
+( cd lib ; ln -sf libss.so.2.0 libss.so.2 )
+( cd lib ; rm -rf libe2p.so.2 )
+( cd lib ; ln -sf libe2p.so.2.3 libe2p.so.2 )
 ( cd lib ; rm -rf libuuid.so.1 )
 ( cd lib ; ln -sf libuuid.so.1.2 libuuid.so.1 )
+( cd lib ; rm -rf libext2fs.so.2 )
+( cd lib ; ln -sf libext2fs.so.2.4 libext2fs.so.2 )
